# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ProxyType(str, Enum):
    """
    Type of proxy to use
    """

    """
    allowed enum values
    """
    BASIC = 'basic'
    RESIDENTIAL = 'residential'
    MOBILE = 'mobile'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProxyType from a JSON string"""
        return cls(json.loads(json_str))





# flake8: noqa

# import apis into api package
from asteroid_odyssey.agents_v2_gen.api.agents_api import AgentsApi
from asteroid_odyssey.agents_v2_gen.api.execution_api import ExecutionApi
from asteroid_odyssey.agents_v2_gen.api.files_api import FilesApi

